@@ -632,29 +632,30 @@ plot.lar <- function(x, xvar=c("norm","step","lambda"), breaks=TRUE,
   
   xvar = match.arg(xvar)
   if (xvar=="norm") {
-    x = colSums(abs(beta))
+    xx = colSums(abs(beta))
     xlab = "L1 norm"
   } else if (xvar=="step") {
-    x = 1:k
+    xx = 1:k
     xlab = "Step"
   } else {
-    x = lambda
+    xx = lambda
     xlab = "Lambda"
   }
 
   if (omit.zeros) {
-    inds = matrix(FALSE,p,k)
-    for (i in 1:k) {
-      inds[i,] = beta[i,]!=0 | c(diff(beta[i,]!=0),F) | c(F,diff(beta[i,]!=0))
-    }
-    beta[!inds] = NA
+    good.inds = matrix(FALSE,p,k)
+    good.inds[beta!=0] = TRUE
+    changes = t(apply(beta,1,diff))!=0
+    good.inds[cbind(changes,rep(F,p))] = TRUE
+    good.inds[cbind(rep(F,p),changes)] = TRUE
+    beta[!good.inds] = NA
   }
 
-  plot(c(),c(),xlim=range(x,na.rm=T),ylim=range(beta,na.rm=T),
-       xlab=xlab,ylab="Coefficients",main="LAR path",...)
+  plot(c(),c(),xlim=range(xx,na.rm=T),ylim=range(beta,na.rm=T),
+       xlab=xlab,ylab="Coefficients",main="Least angle regression path",...)
   abline(h=0,lwd=2)
-  matplot(x,t(beta),type="l",lty=1,add=TRUE)
-  if (breaks) abline(v=x,lty=2)
+  matplot(xx,t(beta),type="l",lty=1,add=TRUE)
+  if (breaks) abline(v=xx,lty=2)
   if (var.labels) axis(4,at=beta[,k],labels=1:p,cex=0.8,adj=0) 
   invisible()
 }
